Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1865)

Unified Diff: Source/modules/webaudio/AudioBufferSourceNode.h

Issue 349213007: WebAudio: Remove AudioNode::RefType. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Fix webaudio/delaynode-max-nondefault-delay.html Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/modules/webaudio/AudioBufferSourceNode.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/modules/webaudio/AudioBufferSourceNode.h
diff --git a/Source/modules/webaudio/AudioBufferSourceNode.h b/Source/modules/webaudio/AudioBufferSourceNode.h
index cb24a38c09abeaf47b8781f3a3c48fec9ed56821..907b1e40295c939759ea2a6b2bdf35b6908eaeca 100644
--- a/Source/modules/webaudio/AudioBufferSourceNode.h
+++ b/Source/modules/webaudio/AudioBufferSourceNode.h
@@ -130,9 +130,12 @@ private:
// It incorporates the base pitch rate, any sample-rate conversion factor from the buffer, and any doppler shift from an associated panner node.
double totalPitchRate();
- // We optionally keep track of a panner node which has a doppler shift that is incorporated into
- // the pitch rate. We manually manage ref-counting because we want to use RefTypeConnection.
- PannerNode* m_pannerNode;
+ // We optionally keep track of a panner node which has a doppler shift that
+ // is incorporated into the pitch rate.
+ // This RefPtr is connection reference. We must call AudioNode::
+ // makeConnection() after ref(), and call AudioNode::breakConnection()
+ // before deref().
+ RefPtr<PannerNode> m_pannerNode;
// This synchronizes process() with setBuffer() which can cause dynamic channel count changes.
mutable Mutex m_processLock;
« no previous file with comments | « no previous file | Source/modules/webaudio/AudioBufferSourceNode.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698